@@ -1,27 +1,19 @@
-# PMML: Predictive Modelling Markup Language
+# PMML: Predictive Model Markup Language
 #
-# Part of the Rattle package for Data Mining
+# Copyright (c) 2009-2013, some parts by Togaware Pty Ltd and other by Zementis, Inc. 
 #
-# Handle glm models.
+# This file is part of the PMML package for R.
 #
-# Time-stamp: <2012-12-04 05:35:09 Graham Williams>
+# The PMML package is free software: you can redistribute it and/or 
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 2 of 
+# the License, or (at your option) any later version.
 #
-# Copyright (c) 2009 Togaware Pty Ltd
-#
-# This files is part of the Rattle suite for Data Mining in R.
-#
-# Rattle is free software: you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 2 of the License, or
-# (at your option) any later version.
-#
-# Rattle is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Rattle. If not, see <http://www.gnu.org/licenses/>.
+# The PMML package is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. Please see the
+# GNU General Public License for details (http://www.gnu.org/licenses/).
+######################################################################################
 
 ########################################################################
 # Linear Model PMML exporter
@@ -43,16 +35,15 @@ pmml.glm <- function(model,
                     description="Generalized Linear Regression Model",
                     copyright=NULL,
                     transforms=NULL,
+                    weights=NULL,
                     ...)
 {
-  if (! inherits(model, "glm")) stop("Not a legitimate lm object")
-  #require(XML, quietly=TRUE)
+  if (! inherits(model, "glm")) stop("Not a legitimate glm object")
 
   # Collect the required information.
 
-  # For a regression, all variables will have been used except those
-  # with a NA coefficient indicating singularities. We mark
-  # singularities as inactive shortly.
+  # For a regression, all variables will have been used except those with a NA coefficient
+  # indicating singularities. We mark singularities as inactive shortly.
 
   terms <- attributes(model$terms)
   
@@ -70,13 +61,6 @@ pmml.glm <- function(model,
   if (length(weights)) field$class <- field$class[-weights]
   orig.class <- field$class
 
-  # 090103 Support transforms if available.
-
-  if (.supportTransformExport(transforms))
-  {
-    field <- .unifyTransforms(field, transforms)
-    transforms <- .activateDependTransforms(transforms)
-  }
   number.of.fields <- length(field$name)
 
   target <- field$name[1]
@@ -298,7 +282,7 @@ pmml.glm <- function(model,
 
   # PMML -> RegressionModel -> MiningSchema
 
-  the.model <- append.XMLNode(the.model, .pmmlMiningSchema(field, target, inactive, transforms))
+  the.model <- append.XMLNode(the.model, .pmmlMiningSchema(field, target, transforms))
 
   if(categ)
   {
@@ -315,16 +299,13 @@ pmml.glm <- function(model,
   }
   the.model <- append.XMLNode(the.model, outn)
 
-
+  #---------------------------------------------------
   # PMML -> TreeModel -> LocalTransforms
 
-  if (.supportTransformExport(transforms))
-    the.model <- append.XMLNode(the.model, .gen.transforms(transforms))
-
   # test of Zementis xform functions
   if(!is.null(transforms))
   {
-    the.model <- append.XMLNode(the.model, pmmlLocalTransformations(field, transforms))
+    the.model <- append.XMLNode(the.model, .pmmlLocalTransformations(field, transforms))
   }
 
  plNode <- xmlNode("ParameterList")
